@@ -71,7 +71,7 @@ def smart_synonyms(word, lang=None, initial_synonyms_list=None):
     retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
     s.mount('https://', HTTPAdapter(max_retries=retries))
 
-    url = url_list['BASE_URL_SMART_SYNONYM_PROD']
+    url = url_list['BASE_URL_SMART_SYNONYM_PROD'] + "/synonym"
 
     data = {
         "word": word,
@@ -91,6 +91,39 @@ def smart_synonyms(word, lang=None, initial_synonyms_list=None):
         logging.error(str(e))
 
 
+# SmartSubstitution
+def smart_substitution(sentence):
+
+    if sentence != "" and "<mask>" in sentence:
+        # Google Pod
+        headers = {
+            "Content-Type": "application/json"
+        }
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        url = url_list['BASE_URL_SMARTJOIN_DEV'] + "/substitute_word"
+
+        data = {
+            "sentence": sentence
+        }
+
+        r = s.post(url=url, headers=headers, json=data)
+        r.raise_for_status()
+
+        try:
+            dict_response = r.json()
+            response = dict_response['response']
+            return response
+        except Exception as e:
+            logging.error(str(e))
+    else:
+        print("No substitution needed. Empty string or <mask> not in input sentence.")
+
+
 # SmartOpenData
 def smart_opendata(sentence, language="en", show_header=False, dataset_score_dict=None, boost_columns=False,
                 boost_name_score=False, use_domains=True, store_df=True):
